==> codeready-workspaces-stacks-php-rhel8-container-2.14-7.tar.gz: asset-php-s390x/composer/installed.php <==
<?php return array(
    'root' => array(
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'reference' => NULL,
        'name' => '__root__',
        'dev' => true,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'reference' => NULL,
            'dev_requirement' => false,
        ),
        'composer/xdebug-handler' => array(
            'pretty_version' => '1.4.6',
            'version' => '1.4.6.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/./xdebug-handler',
            'aliases' => array(),
            'reference' => 'f27e06cd9675801df441b3656569b328e04aa37c',
            'dev_requirement' => false,
        ),
        'felixfbecker/advanced-json-rpc' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/advanced-json-rpc',
            'aliases' => array(),
            'reference' => 'b5f37dbff9a8ad360ca341f3240dc1c168b45447',
            'dev_requirement' => false,
        ),
        'felixfbecker/language-server' => array(
            'pretty_version' => 'v5.4.6',
            'version' => '5.4.6.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/language-server',
            'aliases' => array(),
            'reference' => '1da3328bc23ebd6418529035d357481c8c028640',
            'dev_requirement' => false,
        ),
        'felixfbecker/language-server-protocol' => array(
            'pretty_version' => '1.5.1',
            'version' => '1.5.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/language-server-protocol',
            'aliases' => array(),
            'reference' => '9d846d1f5cf101deee7a61c8ba7caa0a975cd730',
            'dev_requirement' => false,
        ),
        'jetbrains/phpstorm-stubs' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jetbrains/phpstorm-stubs',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'reference' => '116344bbf406467fde34e8b49aad20a1de5ffb44',
            'dev_requirement' => false,
        ),
        'microsoft/tolerant-php-parser' => array(
            'pretty_version' => 'v0.0.23',
            'version' => '0.0.23.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../microsoft/tolerant-php-parser',
            'aliases' => array(),
            'reference' => '1d76657e3271754515ace52501d3e427eca42ad0',
            'dev_requirement' => false,
        ),
        'netresearch/jsonmapper' => array(
            'pretty_version' => 'v1.6.0',
            'version' => '1.6.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../netresearch/jsonmapper',
            'aliases' => array(),
            'reference' => '0d4d1b48d682a93b6bfedf60b88c7750e9cb0b06',
            'dev_requirement' => false,
        ),
        'phpdocumentor/reflection-common' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/reflection-common',
            'aliases' => array(),
            'reference' => '1d01c49d4ed62f25aa84a747ad35d5a16924662b',
            'dev_requirement' => false,
        ),
        'phpdocumentor/reflection-docblock' => array(
            'pretty_version' => '4.3.4',
            'version' => '4.3.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/reflection-docblock',
            'aliases' => array(),
            'reference' => 'da3fd972d6bafd628114f7e7e036f45944b62e9c',
            'dev_requirement' => false,
        ),
        'phpdocumentor/type-resolver' => array(
            'pretty_version' => '1.5.1',
            'version' => '1.5.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/type-resolver',
            'aliases' => array(),
            'reference' => 'a12f7e301eb7258bb68acd89d4aefa05c2906cae',
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'dev_requirement' => false,
        ),
        'sabre/event' => array(
            'pretty_version' => '5.1.4',
            'version' => '5.1.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/event',
            'aliases' => array(),
            'reference' => 'd7da22897125d34d7eddf7977758191c06a74497',
            'dev_requirement' => false,
        ),
        'sabre/uri' => array(
            'pretty_version' => '2.2.2',
            'version' => '2.2.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/uri',
            'aliases' => array(),
            'reference' => '7cb0f489578afad5006e85cd60f18ff33f2d440d',
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.23.0',
            'version' => '1.23.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'reference' => '46cd95797e9df938fdd2b03693b5fca5e64b01ce',
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.10.0',
            'version' => '1.10.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'reference' => '6964c76c7804814a842473e0c8fd15bab0f18e25',
            'dev_requirement' => false,
        ),
        'webmozart/glob' => array(
            'pretty_version' => '4.4.0',
            'version' => '4.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/glob',
            'aliases' => array(),
            'reference' => '539b5dbc10021d3f9242e7a9e9b6b37843179e83',
            'dev_requirement' => false,
        ),
        'webmozart/path-util' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/path-util',
            'aliases' => array(),
            'reference' => 'd939f7edc24c9a1bb9c0dee5cb05d8e859490725',
            'dev_requirement' => false,
        ),
    ),
);

==> codeready-workspaces-stacks-php-rhel8-container-2.15-10.1645828339.tar.gz: asset-php-s390x/composer/installed.php <==
<?php return array(
    'root' => array(
        'pretty_version' => '1.0.0+no-version-set',
        'version' => '1.0.0.0',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'reference' => NULL,
        'name' => '__root__',
        'dev' => true,
    ),
    'versions' => array(
        '__root__' => array(
            'pretty_version' => '1.0.0+no-version-set',
            'version' => '1.0.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'reference' => NULL,
            'dev_requirement' => false,
        ),
        'composer/xdebug-handler' => array(
            'pretty_version' => '1.4.6',
            'version' => '1.4.6.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/./xdebug-handler',
            'aliases' => array(),
            'reference' => 'f27e06cd9675801df441b3656569b328e04aa37c',
            'dev_requirement' => false,
        ),
        'felixfbecker/advanced-json-rpc' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/advanced-json-rpc',
            'aliases' => array(),
            'reference' => 'b5f37dbff9a8ad360ca341f3240dc1c168b45447',
            'dev_requirement' => false,
        ),
        'felixfbecker/language-server' => array(
            'pretty_version' => 'v5.4.6',
            'version' => '5.4.6.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/language-server',
            'aliases' => array(),
            'reference' => '1da3328bc23ebd6418529035d357481c8c028640',
            'dev_requirement' => false,
        ),
        'felixfbecker/language-server-protocol' => array(
            'pretty_version' => '1.5.1',
            'version' => '1.5.1.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../felixfbecker/language-server-protocol',
            'aliases' => array(),
            'reference' => '9d846d1f5cf101deee7a61c8ba7caa0a975cd730',
            'dev_requirement' => false,
        ),
        'jetbrains/phpstorm-stubs' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'type' => 'library',
            'install_path' => __DIR__ . '/../jetbrains/phpstorm-stubs',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'reference' => '419389d409990c0e4cdd1f5f5c560f0a8ea333d1',
            'dev_requirement' => false,
        ),
        'microsoft/tolerant-php-parser' => array(
            'pretty_version' => 'v0.0.23',
            'version' => '0.0.23.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../microsoft/tolerant-php-parser',
            'aliases' => array(),
            'reference' => '1d76657e3271754515ace52501d3e427eca42ad0',
            'dev_requirement' => false,
        ),
        'netresearch/jsonmapper' => array(
            'pretty_version' => 'v1.6.0',
            'version' => '1.6.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../netresearch/jsonmapper',
            'aliases' => array(),
            'reference' => '0d4d1b48d682a93b6bfedf60b88c7750e9cb0b06',
            'dev_requirement' => false,
        ),
        'phpdocumentor/reflection-common' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/reflection-common',
            'aliases' => array(),
            'reference' => '1d01c49d4ed62f25aa84a747ad35d5a16924662b',
            'dev_requirement' => false,
        ),
        'phpdocumentor/reflection-docblock' => array(
            'pretty_version' => '4.3.4',
            'version' => '4.3.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/reflection-docblock',
            'aliases' => array(),
            'reference' => 'da3fd972d6bafd628114f7e7e036f45944b62e9c',
            'dev_requirement' => false,
        ),
        'phpdocumentor/type-resolver' => array(
            'pretty_version' => '1.6.0',
            'version' => '1.6.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpdocumentor/type-resolver',
            'aliases' => array(),
            'reference' => '93ebd0014cab80c4ea9f5e297ea48672f1b87706',
            'dev_requirement' => false,
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'dev_requirement' => false,
        ),
        'sabre/event' => array(
            'pretty_version' => '5.1.4',
            'version' => '5.1.4.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/event',
            'aliases' => array(),
            'reference' => 'd7da22897125d34d7eddf7977758191c06a74497',
            'dev_requirement' => false,
        ),
        'sabre/uri' => array(
            'pretty_version' => '2.2.2',
            'version' => '2.2.2.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/uri',
            'aliases' => array(),
            'reference' => '7cb0f489578afad5006e85cd60f18ff33f2d440d',
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.24.0',
            'version' => '1.24.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'reference' => '30885182c981ab175d4d034db0f6f469898070ab',
            'dev_requirement' => false,
        ),
        'webmozart/assert' => array(
            'pretty_version' => '1.10.0',
            'version' => '1.10.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/assert',
            'aliases' => array(),
            'reference' => '6964c76c7804814a842473e0c8fd15bab0f18e25',
            'dev_requirement' => false,
        ),
        'webmozart/glob' => array(
            'pretty_version' => '4.4.0',
            'version' => '4.4.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/glob',
            'aliases' => array(),
            'reference' => '539b5dbc10021d3f9242e7a9e9b6b37843179e83',
            'dev_requirement' => false,
        ),
        'webmozart/path-util' => array(
            'pretty_version' => '2.3.0',
            'version' => '2.3.0.0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../webmozart/path-util',
            'aliases' => array(),
            'reference' => 'd939f7edc24c9a1bb9c0dee5cb05d8e859490725',
            'dev_requirement' => false,
        ),
    ),
);
